@@ -9,6 +9,7 @@ logger = logging.getLogger(__name__)
 class CoreConfig:
     ROOT_DIR = ".ai-kit"
     INDEX_DIR = "files"  # Directory for indexed content
+    CHAT_DIR = "chats"  # Directory for chat history
     SUPPORTED_FILE_EXTENSIONS = [".txt", ".md", ".pdf"]
 
 
@@ -27,6 +28,7 @@ class LiteLLMConfig:
         "llama-3.1-8B-instruct",
         "llama-3.1-70B-instruct",
         "llama-3.3-70b-versatile",
+        "claude-3.5-sonnet",
     ]
     SUPPORTED_REASONING_MODELS = [
         "o1-mini",
@@ -34,6 +36,7 @@ class LiteLLMConfig:
         "r1",
         "o3-mini",
         "gemini-2.0-flash-thinking",
+        "r1-together",
     ]
     SUPPORTED_EMBEDDING_MODELS = ["text-embedding-3-small", "text-embedding-3-large"]
 
@@ -44,10 +47,12 @@ class LiteLLMConfig:
         # together
         "llama-3.1-8B-instruct": "together_ai/meta-llama/Meta-Llama-3.1-8B-Instruct-Turbo",
         "llama-3.1-70B-instruct": "together_ai/meta-llama/Meta-Llama-3.1-70B-Instruct-Turbo",
+        "r1-together": "deepseek-ai/Deepseek-R1",
         # gemini
         "gemini-2.0-flash-thinking": "gemini-2.0-flash-thinking-exp-01-21",
         # groq
         "llama-3.3-70b-versatile": "groq/llama-3.3-70b-versatile",
+        "claude-3.5-sonnet": "anthropic/claude-3-5-sonnet-latest",
     }
 
     # Required API keys for different providers (optional)
@@ -57,8 +62,10 @@ class LiteLLMConfig:
         "o3-mini": "OPENAI_API_KEY",
         "gpt-4o": "OPENAI_API_KEY",
         "r1": "DEEPSEEK_API_KEY",
+        "r1-together": "TOGETHER_API_KEY",
         "llama-3.1-8B-instruct": "TOGETHER_API_KEY",
         "gemini-2.0-flash-thinking": "GEMINI_API_KEY",
+        "claude-3.5-sonnet": "ANTHROPIC_API_KEY",
     }
 
     # Model dimension mappings for embeddings
